@@ -37,5 +37,5 @@ class QueryDB:
         self.filepath = filepath
 
     def search(self,mapList):
-        myDict = getDict("test.json")
-        print(JSONPath(f"$..{mapList}").parse(myDict))
+        myDict = getDict(self.filepath)
+        return JSONPath(f"$..{mapList}").parse(myDict)
