@@ -13,16 +13,17 @@ def setInDict(fileName,mapList, value,indent):
     getFromDict(dataDict, mapList[:-1])[mapList[-1]] = value
     writePath = open(fileName,'w')
     json.dump(dataDict,writePath,indent=indent)
-
+    
 def delInDict(fileName,mapList,indent):
     if indent == 0:
         indent = None
     mapList = mapList.split('.')
+    writePath = open(fileName,'w')
+    if mapList[0] == "All":
+        writePath.write("{}")
+        return
     dataDict = json.load(open(fileName,'r'))
     del getFromDict(dataDict, mapList[:-1])[mapList[-1]]
-    writePath = open(fileName,'w')
-    if mapList == "All":
-        writePath.write("{}")
     json.dump(dataDict,writePath,indent=indent)
 
 def appendInDict(fileName,mapList, value,indent):
